diff --git a/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererHuman.java b/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererHuman.java
index f87c43905..010ba3e13 100644
--- a/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererHuman.java
+++ b/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererHuman.java
@@ -41,6 +41,11 @@ public class MobRendererHuman extends MobRendererBiped<MobHuman>
 
     @Override
     protected @Nullable StaticEntityModel getActiveModel(@NotNull final MobHuman entity) {
+        if (isASign(entity)) return getModel("main.shign");
         return entity.slimModel ? getModel("main.slim") : getModel("main");
     }
+
+    public static boolean isASign(@NotNull final MobHuman human) {
+        return human.nickname.equals("ShignBright");
+    }
 }
diff --git a/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererPlayer.java b/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererPlayer.java
index f9accee20..087eccbf0 100644
--- a/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererPlayer.java
+++ b/game/client/src/main/java/net/minecraft/client/render/entity/MobRendererPlayer.java
@@ -24,8 +24,11 @@ import org.lwjgl.opengl.GL11;
 import org.useless.dragonfly.models.entity.BoneTransform;
 import org.useless.dragonfly.models.entity.StaticEntityModel;
 
+import java.util.UUID;
+
 public class MobRendererPlayer extends MobRendererBipedArmored<Player>
 {
+    public static final UUID UUID_SHIGN = UUID.fromString("49f6ea39-30b2-4441-b07c-7bfe0beeb61e");
     private BlocksContainer container = null;
 
     public MobRendererPlayer()
@@ -37,6 +40,7 @@ public class MobRendererPlayer extends MobRendererBipedArmored<Player>
         if (onlyArms) {
             return player.slimModel ? getModel("arms.slim") : getModel("arms");
         } else {
+            if (isASign(player)) return getModel("main.shign");
             return player.slimModel ? getModel("main.slim") : getModel("main");
         }
     }
@@ -266,6 +270,7 @@ public class MobRendererPlayer extends MobRendererBipedArmored<Player>
 
     @Override
     protected @Nullable StaticEntityModel getActiveModel(@NotNull final Player entity) {
+        if (isASign(entity)) return getModel("main.shign");
         return entity.slimModel ? getModel("main.slim") : getModel("main");
     }
 
@@ -299,4 +304,8 @@ public class MobRendererPlayer extends MobRendererBipedArmored<Player>
     public void loadEntityTexture(final @NotNull Player entity) {
         bindDownloadableTexture(entity.skinURL, entity.getEntityTexture(), PlayerSkinParser.instance);
     }
+
+    public static boolean isASign(@NotNull final Player player) {
+        return player.uuid.equals(UUID_SHIGN) || player.username.equals("ShignBright");
+    }
 }
diff --git a/game/client/src/main/resources/assets/minecraft/models/entity/models.json b/game/client/src/main/resources/assets/minecraft/models/entity/models.json
index a2ac6a30f..49c14cc39 100644
--- a/game/client/src/main/resources/assets/minecraft/models/entity/models.json
+++ b/game/client/src/main/resources/assets/minecraft/models/entity/models.json
@@ -19,6 +19,7 @@
         "/assets/minecraft/models/entity/boat/boat.geo.json",
         "/assets/minecraft/models/entity/cannonball/cannonball.geo.json",
         "/assets/minecraft/models/entity/humanoid.geo.json",
+        "/assets/minecraft/models/entity/secret.geo.json",
         "/assets/minecraft/models/entity/player/player.geo.json",
         "/assets/minecraft/models/entity/sign/sign.geo.json",
         "/assets/minecraft/models/entity/flag/flag.geo.json"
@@ -88,6 +89,7 @@
         "minecraft:player": {
             "main":"geometry.player.base.steve",
             "main.slim":"geometry.player.base.alex",
+            "main.shign":"geometry.player.base.shign",
             "arms":"geometry.player.base.steve.arms",
             "arms.slim":"geometry.player.base.alex.arms",
             "cape":"geometry.player.cape",
@@ -99,6 +101,7 @@
         "minecraft:human": {
             "main":"geometry.player.base.steve",
             "main.slim":"geometry.player.base.alex",
+            "main.shign":"geometry.player.base.shign",
             "arms":"geometry.player.base.steve.arms",
             "arms.slim":"geometry.player.base.alex.arms",
             "cape":"geometry.player.cape"
diff --git a/game/client/src/main/resources/assets/minecraft/models/entity/secret.geo.json b/game/client/src/main/resources/assets/minecraft/models/entity/secret.geo.json
new file mode 100644
index 000000000..2c427a6d2
--- /dev/null
+++ b/game/client/src/main/resources/assets/minecraft/models/entity/secret.geo.json
@@ -0,0 +1,178 @@
+{
+	"format_version": "1.12.0",
+	"minecraft:geometry": [
+		{
+			"description": {
+				"identifier": "geometry.player.base.shign",
+				"texture_width": 64,
+				"texture_height": 64,
+				"visible_bounds_width": 3,
+				"visible_bounds_height": 4,
+				"visible_bounds_offset": [0, 2, 0]
+			},
+			"bones": [
+				{
+					"name": "waist",
+					"pivot": [0, 12, 0]
+				},
+				{
+					"name": "body",
+					"parent": "waist",
+					"pivot": [0, 24, 0]
+				},
+				{
+					"name": "torso",
+					"parent": "body",
+					"pivot": [0, 24, 0],
+					"cubes": [
+						{"origin": [-4, 12, -2], "size": [8, 12, 4], "uv": [16, 16]}
+					]
+				},
+				{
+					"name": "jacket",
+					"parent": "torso",
+					"pivot": [0, 18, 0],
+					"cubes": [
+						{"origin": [-4, 12, -2], "size": [8, 12, 4], "inflate": 0.25, "uv": [16, 32]}
+					]
+				},
+				{
+					"name": "rightArm",
+					"parent": "torso",
+					"pivot": [-5, 22, 0],
+					"cubes": [
+						{"origin": [-7, 12, -2], "size": [3, 12, 4], "uv": [40, 16]}
+					]
+				},
+				{
+					"name": "rightSleeve",
+					"parent": "rightArm",
+					"pivot": [-6, 18, 0],
+					"cubes": [
+						{"origin": [-7, 12, -2], "size": [3, 12, 4], "inflate": 0.25, "uv": [40, 32]}
+					]
+				},
+				{
+					"name": "rightItem",
+					"parent": "rightArm",
+					"pivot": [-5.5, 12, -2],
+					"rotation": [90, 0, 0]
+				},
+				{
+					"name": "leftArm",
+					"parent": "torso",
+					"pivot": [5, 22, 0],
+					"cubes": [
+						{"origin": [4, 12, -2], "size": [3, 12, 4], "uv": [32, 48]}
+					]
+				},
+				{
+					"name": "leftSleeve",
+					"parent": "leftArm",
+					"pivot": [5, 18, 0],
+					"cubes": [
+						{"origin": [4, 12, -2], "size": [3, 12, 4], "inflate": 0.25, "uv": [48, 48]}
+					]
+				},
+				{
+					"name": "leftItem",
+					"parent": "leftArm",
+					"pivot": [5.5, 12, -2],
+					"rotation": [-90, 180, 0]
+				},
+				{
+					"name": "cape",
+					"parent": "torso",
+					"pivot": [0, 24, 2.5]
+				},
+				{
+					"name": "head",
+					"parent": "body",
+					"pivot": [0, 24, 0],
+					"cubes": [
+						{
+							"origin": [0, 26, -2],
+							"size": [9, 10, 4],
+							"uv": {
+								"north": {"uv": [64, 16], "uv_size": [-9, 10]},
+								"south": {"uv": [64, 30], "uv_size": [-9, 10]},
+								"west": {"uv": [54, 26], "uv_size": [10, 4], "uv_rotation": 270},
+								"up": {"uv": [55, 26], "uv_size": [9, 4], "uv_rotation": 180},
+								"down": {"uv": [55, 30], "uv_size": [9, -4], "uv_rotation": 180}
+							}
+						},
+						{
+							"origin": [-9, 26, -2],
+							"size": [9, 10, 4],
+							"uv": {
+								"north": {"uv": [55, 16], "uv_size": [9, 10]},
+								"east": {"uv": [54, 26], "uv_size": [10, 4], "uv_rotation": 90},
+								"south": {"uv": [55, 30], "uv_size": [9, 10]},
+								"up": {"uv": [55, 26], "uv_size": [9, 4], "uv_rotation": 180},
+								"down": {"uv": [55, 30], "uv_size": [9, -4], "uv_rotation": 180}
+							}
+						},
+						{
+							"origin": [-1, 23, -1],
+							"size": [2, 3, 2],
+							"uv": {
+								"north": {"uv": [62, 42], "uv_size": [2, 3]},
+								"east": {"uv": [62, 42], "uv_size": [2, 3]},
+								"south": {"uv": [62, 42], "uv_size": [2, 3]},
+								"west": {"uv": [62, 42], "uv_size": [2, 3]},
+								"up": {"uv": [62, 40], "uv_size": [2, 2]},
+								"down": {"uv": [62, 42], "uv_size": [2, -2]}
+							}
+						}
+					]
+				},
+				{
+					"name": "hat",
+					"parent": "head",
+					"pivot": [0, 28, 0],
+					"cubes": [
+						{
+							"origin": [-12, 33, 0],
+							"size": [8, 8, 0],
+							"uv": {
+								"north": {"uv": [56, 0], "uv_size": [8, 8]}
+							}
+						}
+					]
+				},
+				{
+					"name": "rightLeg",
+					"parent": "body",
+					"pivot": [-1.9, 12, 0],
+					"cubes": [
+						{"origin": [-4, 0, -2], "size": [4, 12, 4], "uv": [0, 16]}
+					]
+				},
+				{
+					"name": "rightPant",
+					"parent": "rightLeg",
+					"pivot": [-2, 6, 0],
+					"cubes": [
+						{"origin": [-4, 0, -2], "size": [4, 12, 4], "inflate": 0.25, "uv": [0, 32]}
+					]
+				},
+				{
+					"name": "leftLeg",
+					"parent": "body",
+					"pivot": [1.9, 12, 0],
+					"cubes": [
+						{"origin": [0, 0, -2], "size": [4, 12, 4], "uv": [16, 48]}
+					]
+				},
+				{
+					"name": "leftPant",
+					"parent": "leftLeg",
+					"pivot": [2, 6, 0],
+					"cubes": [
+						{"origin": [0, 0, -2], "size": [4, 12, 4], "inflate": 0.25, "uv": [0, 48]}
+					]
+				}
+			]
+		}
+	]
+}
\ No newline at end of file
